@@ -7,6 +7,8 @@
 /* include this first, before NO_IMPORT_PYGOBJECT is defined */
 #include <pygobject.h>
 
+#include "gconf-types.h"
+
 void pygconf_register_classes (PyObject *d);
 void pygconf_add_constants(PyObject *module, const gchar *strip_prefix);
 		
@@ -24,8 +26,5 @@ initgconf (void)
 
 	pygconf_register_classes (d);
 	pygconf_add_constants (m, "GCONF_");
-	
-	if (PyErr_Occurred ()) {
-		Py_FatalError ("can't initialise module gconf");
-	}
+	pygconf_register_engine_type (m);
 }
